Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(52)

Unified Diff: src/images/SkImageDecoder_FactoryDefault.cpp

Issue 1316233002: Style Change: NULL->nullptr (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: 2015-08-27 (Thursday) 10:25:06 EDT Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/images/SkImageDecoder.cpp ('k') | src/images/SkImageDecoder_FactoryRegistrar.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/images/SkImageDecoder_FactoryDefault.cpp
diff --git a/src/images/SkImageDecoder_FactoryDefault.cpp b/src/images/SkImageDecoder_FactoryDefault.cpp
index e959c8b69b8144ca0b501e77fd8d5a0e965e9a8a..77c0a0ac578ffc3fd20bd8312472c08db91f05db 100644
--- a/src/images/SkImageDecoder_FactoryDefault.cpp
+++ b/src/images/SkImageDecoder_FactoryDefault.cpp
@@ -27,10 +27,10 @@ SkMovie* SkMovie::DecodeStream(SkStreamRewindable* stream) {
if (movie) {
return movie;
}
// we must rewind only if we got NULL, since we gave the stream to the
// movie, who may have already started reading from it
stream->rewind();
curr = curr->next();
}
- return NULL;
+ return nullptr;
}
« no previous file with comments | « src/images/SkImageDecoder.cpp ('k') | src/images/SkImageDecoder_FactoryRegistrar.cpp » ('j') | no next file with comments »
@@ -27,10 +27,10 @@ SkMovie* SkMovie::DecodeStream(SkStreamRewindable* stream) {
return movie;
}
- // we must rewind only if we got NULL, since we gave the stream to the
+ // we must rewind only if we got nullptr, since we gave the stream to the
// movie, who may have already started reading from it
stream->rewind();

Powered by Google App Engine
This is Rietveld 408576698